Module: Google::Cloud::WebSecurityScanner
- Defined in:
- lib/google/cloud/web_security_scanner.rb,
lib/google/cloud/web_security_scanner/version.rb
Constant Summary collapse
- VERSION =
"0.1.2"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.web_security_scanner| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-web_security_scanner library.
-
.web_security_scanner(version: :v1, &block) ⇒ WebSecurityScanner::Client
Create a new client object for WebSecurityScanner.
Class Method Details
.configure {|::Google::Cloud.configure.web_security_scanner| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-web_security_scanner library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional gRPC headers to be sent with the call.-
retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys:* `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. * `:retry_codes` (*type:* `Array<String>`) - The error codes that should trigger a retry.
107 108 109 110 111 |
# File 'lib/google/cloud/web_security_scanner.rb', line 107 def self.configure yield ::Google::Cloud.configure.web_security_scanner if block_given? ::Google::Cloud.configure.web_security_scanner end |
.web_security_scanner(version: :v1, &block) ⇒ WebSecurityScanner::Client
Create a new client object for WebSecurityScanner.
By default, this returns an instance of
Google::Cloud::WebSecurityScanner::V1::WebSecurityScanner::Client
for version V1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the WebSecurityScanner service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About WebSecurityScanner
Web Security Scanner Service identifies security vulnerabilities in web applications hosted on Google Cloud. It crawls your application, and attempts to exercise as many user inputs and event handlers as possible.
68 69 70 71 72 73 74 75 76 77 |
# File 'lib/google/cloud/web_security_scanner.rb', line 68 def self.web_security_scanner version: :v1, &block require "google/cloud/web_security_scanner/#{version.to_s.downcase}" package_name = Google::Cloud::WebSecurityScanner .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::WebSecurityScanner.const_get package_name package_module.const_get(:WebSecurityScanner).const_get(:Client).new(&block) end |